@@ -1,4 +1,4 @@
-from trame import get_app_instance
+from trame.internal.app import get_app_instance
 from trame.html import AbstractElement
 
 MODULE = None
@@ -179,32 +179,41 @@ class VtkRemoteLocalView(AbstractElement):
     ... )
     """
 
-    def __init__(self, view, **kwargs):
+    def __init__(self, view, enable_rendering=True, **kwargs):
         super().__init__("vtk-remote-local-view", **kwargs)
-        __ns = kwargs["namespace"]
-
-        # !!! HACK !!!
-        # Allow user to configure view mode by providing (, local/remote)
-        __rmode = "remote"
-        __mode_arg = kwargs.get("mode", (f"{__ns}Mode",))
-        if __mode_arg and isinstance(__mode_arg, (tuple, list)) and len(__mode_arg) > 1:
-            __rmode = __mode_arg[1]
-            self._attributes["mode"] = f':mode="{__mode_arg[0]}"'
-        elif __mode_arg and isinstance(__mode_arg, (tuple, list)):
-            self._attributes["mode"] = f':mode="{__mode_arg[0]}"'
-        elif __mode_arg and isinstance(__mode_arg, str):
-            self._attributes["mode"] = f'mode="{__mode_arg}"'
-        # !!! HACK !!!
-
+        self.__app = get_app_instance()
+        __ns = kwargs.get("namespace", "view")
+        self.__mode_key = f"{__ns}Mode"
         self.__scene_id = f"{__ns}Scene"
+        self.__ref = kwargs.get("ref", __ns)
+        self.__rendering = enable_rendering
+
+        # !!! HACK !!!
+        # Allow user to configure view mode by providing (..., local/remote) and or "local/remote"
+        __mode_expression = kwargs.get("mode", self.__mode_key)
+        __mode_start = "remote"
+        if isinstance(__mode_expression, (tuple, list)):
+            if len(__mode_expression) == 2:
+                __mode_expression, __mode_start = __mode_expression
+            else:
+                __mode_expression = __mode_expression[0]
+        elif __mode_expression in ["local", "remote"]:
+            __mode_start = __mode_expression
+            __mode_expression = self.__mode_key
+
+        self._attributes["mode"] = f':mode="{__mode_expression}"'
+        # !!! HACK !!!
+
         self.__view_id = MODULE.id(view)
         self.__view = view
-        self.__wrapped_view = MODULE.view(view, __ns, mode=__rmode)
+        self.__wrapped_view = MODULE.view(view, name=__ns, mode=__mode_start)
 
+        # Provide mandatory attributes
         self._attributes["wsClient"] = ':wsClient="wsClient"'
-        self._attributes["ref"] = f'ref="{kwargs.get("ref", __ns)}"'
+        self._attributes["ref"] = f'ref="{self.__ref}"'
         self._attributes["view_id"] = f'id="{self.__view_id}"'
         self._attributes["view_state"] = f':viewState="{self.__scene_id}"'
+        self._attributes["namespace"] = f'namespace="{__ns}"'
 
         self._attr_names += [
             # "mode", # <--- Managed by hand above
@@ -212,7 +221,6 @@ class VtkRemoteLocalView(AbstractElement):
             "interactive_ratio",
             "interactor_events",
             "interactor_settings",
-            "namespace",
         ]
         self._event_names += kwargs.get("interactor_events", [])
 
@@ -220,8 +228,7 @@ class VtkRemoteLocalView(AbstractElement):
         """
         Force update to geometry
         """
-        _app = get_app_instance()
-        _app.set(self.__scene_id, MODULE.scene(self.__view))
+        self.__app.set(self.__scene_id, MODULE.scene(self.__view))
 
     def update_image(self):
         """
@@ -229,6 +236,21 @@ class VtkRemoteLocalView(AbstractElement):
         """
         MODULE.push_image(self.__view)
 
+    def set_local_rendering(self, local=True):
+        self.__app.set(self.__mode_key, "local" if local else "remote")
+
+    def set_remote_rendering(self, remote=True):
+        self.__app.set(self.__mode_key, "remote" if remote else "local")
+
+    def update(self):
+        # need to do both to keep things in sync
+        if self.__rendering:
+            self.update_image()
+        self.update_geometry()
+
+    def reset_camera(self):
+        self.__app.update(ref=self.__ref, method="resetCamera")
+
     @property
     def view(self):
         """
@@ -263,7 +285,9 @@ class VtkRemoteView(AbstractElement):
 
     def __init__(self, view, ref="view", **kwargs):
         super().__init__("vtk-remote-view", **kwargs)
+        self.__app = get_app_instance()
         self.__view = view
+        self.__ref = ref
         self._attributes["wsClient"] = ':wsClient="wsClient"'
         self._attributes["ref"] = f'ref="{ref}"'
         self._attributes["view_id"] = f'id="{MODULE.id(view)}"'
@@ -281,6 +305,9 @@ class VtkRemoteView(AbstractElement):
         """
         MODULE.push_image(self.__view)
 
+    def reset_camera(self):
+        self.__app.update(ref=self.__ref, method="resetCamera")
+
 
 class VtkShareDataset(AbstractElement):
     def __init__(self, children=None, **kwargs):
